cheesecake.cheesecake_index.Step

Package cheesecake :: Module cheesecake_index :: Class Step |
[show private | hide private]
[frames | no frames]

## Type Step

    object --+
             |
            Step

Known Subclasses:
  `StepByVariable`

Single step during computation of package score.

Method Summary
| `__init__(self, provides)`
| ``decide`(self, cheesecake)` Decide if step should be run.
Inherited from object
| ``__delattr__`(...)` x.__delattr__('name') <==> del x.name
| ``__getattribute__`(...)` x.__getattribute__('name') <==> x.name
| ``__hash__`(x)` x.__hash__() <==> hash(x)
| ``__new__`(T, S, ...)` T.__new__(S, ...) -> a new object with type S, a subtype of T
| ``__reduce__`(...)` helper for pickle
| ``__reduce_ex__`(...)` helper for pickle
| ``__repr__`(x)` x.__repr__() <==> repr(x)
| ``__setattr__`(...)` x.__setattr__('name', value) <==> x.name = value
| ``__str__`(x)` x.__str__() <==> str(x)

Method Details

### decide(self, cheesecake) Decide if step should be run. It checks if there's at least one index from current profile that need variables provided by this step. Override this method for other behaviour.

Generated by Epydoc 2.1 on Fri Feb 9 02:15:12 2007 | http://epydoc.sf.net